import React, { useState, useEffect } from 'react';
import { PlusIcon, MinusIcon, ArrowUpIcon, ArrowDownIcon } from 'lucide-react';
import Link from 'next/link';

const AgentInquiry = ({
  agentinquiryCount,
  agentInqData,
  onStatusChange
}) => {
  const [expandedRows, setExpandedRows] = useState({});
  const [sortDirection, setSortDirection] = useState('desc');
  const [sortedData, setSortedData] = useState([]);

  useEffect(() => {
    // Sort data by default when component mounts or when agentInqData changes
    const initialSortedData = [...agentInqData].sort((a, b) => {
      const dateA = new Date(a.created_at);
      const dateB = new Date(b.created_at);
      return dateB - dateA; // Latest first
    });
    setSortedData(initialSortedData);
  }, [agentInqData]);

  const toggleRowExpand = (id) => {
    setExpandedRows(prev => ({
      ...prev,
      [id]: !prev[id] 
    }));
  };

  const toggleSort = () => {
    const newDirection = sortDirection === 'asc' ? 'desc' : 'asc';
    setSortDirection(newDirection);
    
    const sorted = [...sortedData].sort((a, b) => {
      const dateA = new Date(a.created_at);
      const dateB = new Date(b.created_at);
      return newDirection === 'asc' 
        ? dateA - dateB 
        : dateB - dateA;
    });
    
    setSortedData(sorted);
  };

  return (
    <div className="container mx-auto px-4 sm:px-6 lg:px-8 py-4">
      {/* Header Section */}
      <div className="flex flex-col sm:flex-row items-start sm:items-center justify-between mb-6">
        <div className="flex flex-col sm:flex-row items-start sm:items-center space-y-2 sm:space-y-0 sm:space-x-4">
          <h1 className="text-xl sm:text-2xl font-semibold text-gray-900">
            Inquiry To Agent
          </h1> 
          <span className="text-xs bg-green-100 text-green-800 px-2 py-0.5 rounded-full font-semibold">
            Number of Inquiries: {agentinquiryCount}
          </span>
        </div>
        <button
          onClick={toggleSort}
          className="flex items-center space-x-2 px-3 py-2 bg-white border border-gray-300 rounded-md shadow-sm text-sm font-medium text-gray-700 hover:bg-gray-50 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-blue-500 mt-2 sm:mt-0"
        >
          <span>Sort by Date</span>
          {sortDirection === 'asc' ? (
            <ArrowUpIcon className="h-4 w-4" />
          ) : (
            <ArrowDownIcon className="h-4 w-4" />
          )}
        </button>
      </div>

      {/* Properties Table Section */}
      <div className="overflow-x-auto rounded-lg border border-gray-200 bg-white shadow-sm">
        <table className="w-full min-w-full divide-y divide-gray-200">
          {/* Desktop View - Full Table Header */}
          <thead className="bg-gray-50 hidden md:table-header-group">
            <tr>
              <th className="px-2 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider sm:px-4 md:px-6">Properties Images</th>
              <th className="px-2 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider sm:px-4 md:px-6">Owner Details</th>
              <th className="px-2 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider sm:px-4 md:px-6">Inquiry Name</th>
              <th className="px-2 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider sm:px-4 md:px-6">Number</th>
              <th className="px-2 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider sm:px-4 md:px-6">Agree to Contact</th>
              <th className="px-2 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider sm:px-4 md:px-6">Date</th>
            </tr>
          </thead>
          <tbody className="bg-white divide-y divide-gray-200">
            {sortedData.map((inquiry) => (
              <React.Fragment key={inquiry.id}>
                {/* Desktop/Tablet View */}
                <tr className="hover:bg-gray-50 hidden md:table-row">
                  <td className="px-2 py-4 whitespace-nowrap text-sm text-gray-900 sm:px-4 md:px-6">
                    <div className="flex items-center space-x-3">
                      <Link href={`property?postId=${inquiry.post_id}`} as={`/property?postId=${inquiry.post_id}`} target="_blank" rel="noopener noreferrer" className="flex-shrink-0">
                        <img 
                          className="h-14 w-18 sm:h-16 sm:w-18 rounded-md object-cover cursor-pointer hover:opacity-80 transition-opacity" 
                          src={`http://localhost:8000/user-img/user-post-main-img/${inquiry.mainImg}`} 
                          alt="Property" 
                        />
                      </Link>
                      <div className="flex flex-col space-y-1 text-xs text-gray-500">
                        <span>Land Type: {inquiry.propertyTitle}</span>
                        <span>City: {inquiry.propertyCity}</span>
                        <span>Price: ₹{inquiry.price}</span>
                        <span>By {inquiry.owner_role}</span>
                      </div>
                    </div>
                  </td>
                  <td className="px-2 py-4 whitespace-nowrap text-sm text-gray-500 sm:px-4 md:px-6">
                    <div className="flex flex-col space-y-1">
                      <div className="font-medium text-gray-900">{inquiry.owner_name}</div>
                      <div className="text-xs text-gray-500">{inquiry.user_inquiry.email}</div>
                      <div className="text-xs text-gray-500">{inquiry.user_inquiry.mobile_number}</div>
                    </div>
                  </td>
                  <td className="px-2 py-4 whitespace-nowrap text-sm text-gray-500 sm:px-4 md:px-6">
                    <div className="group relative">
                      <div className="truncate max-w-[150px]">{inquiry.enquery_name}</div>
                      <div className="absolute bottom-full left-1/2 transform -translate-x-1/2 mb-2 px-3 py-1 bg-gray-900 text-white text-xs rounded shadow-lg opacity-0 group-hover:opacity-100 transition-opacity duration-200 whitespace-nowrap z-10">
                        {inquiry.enquery_email}
                        <div className="absolute bottom-0 left-1/2 transform -translate-x-1/2 translate-y-full w-2 h-2 bg-gray-900 rotate-45"></div>
                      </div>
                    </div>
                  </td>
                  <td className="px-2 py-4 whitespace-nowrap text-sm text-gray-900 sm:px-4 md:px-6">
                    <div className="truncate max-w-[100px]">{inquiry.enquery_number}</div>
                  </td>
                  <td className="px-2 py-4 whitespace-nowrap text-sm text-gray-500 sm:px-4 md:px-6">
                    <div className="flex items-center justify-center">
                      {inquiry.agree_contact === 1 ? (
                        <svg xmlns="http://www.w3.org/2000/svg" className="h-5 w-5 text-green-500" viewBox="0 0 20 20" fill="currentColor">
                          <path fillRule="evenodd" d="M16.707 5.293a1 1 0 010 1.414l-8 8a1 1 0 01-1.414 0l-4-4a1 1 0 011.414-1.414L8 12.586l7.293-7.293a1 1 0 011.414 0z" clipRule="evenodd" />
                        </svg>
                      ) : (
                        <svg xmlns="http://www.w3.org/2000/svg" className="h-5 w-5 text-red-500" viewBox="0 0 20 20" fill="currentColor">
                          <path fillRule="evenodd" d="M4.293 4.293a1 1 0 011.414 0L10 8.586l4.293-4.293a1 1 0 111.414 1.414L11.414 10l4.293 4.293a1 1 0 01-1.414 1.414L10 11.414l-4.293 4.293a1 1 0 01-1.414-1.414L8.586 10 4.293 5.707a1 1 0 010-1.414z" clipRule="evenodd" />
                        </svg>
                      )}
                    </div>
                  </td>
                  <td className="px-2 py-4 whitespace-nowrap text-sm text-gray-500 sm:px-4 md:px-6">
                    <div className="truncate max-w-[100px]">
                      {new Date(inquiry.created_at).toLocaleDateString('en-GB')}
                    </div>
                  </td>
                </tr>

                {/* Mobile View */}
                <tr className="md:hidden">
                  <td colSpan="6" className="p-4">
                    <div className="flex items-center space-x-3">
                      <div className="relative flex-shrink-0">
                        <Link href={`property?postId=${inquiry.post_id}`} as={`/property?postId=${inquiry.post_id}`} target="_blank" rel="noopener noreferrer">
                          <img 
                            className="h-16 w-20 rounded-md object-cover cursor-pointer hover:opacity-80 transition-opacity" 
                            src={`http://localhost:8000/user-img/user-post-main-img/${inquiry.mainImg}`} 
                            alt="Property" 
                          />
                        </Link>
                        <button 
                          onClick={() => toggleRowExpand(inquiry.id)}
                          className="absolute top-0 right-0 bg-white/70 rounded-full p-1"
                        >
                          {expandedRows[inquiry.id] ? (
                            <MinusIcon className="h-4 w-4 text-gray-700" />
                          ) : (
                            <PlusIcon className="h-4 w-4 text-gray-700" />
                          )}
                        </button>
                      </div>
                      <div className="flex flex-col space-y-1">
                        <h2 className="text-sm font-semibold text-gray-900">
                          {inquiry.propertyTitle}
                        </h2>
                      </div>
                    </div>
                    {expandedRows[inquiry.id] && (
                      <div className="mt-4 space-y-2 text-xs text-gray-600">
                        <div className="grid grid-cols-1 gap-2">
                          <div className="space-y-1">
                            <div className="font-medium">Owner Details:</div>
                            <div className="pl-2">
                              <div>{inquiry.owner_name}</div>
                              <div>{inquiry.user_inquiry.email}</div>
                              <div>{inquiry.user_inquiry.mobile_number}</div>
                            </div>
                          </div>
                          <div className="grid grid-cols-2 gap-2">
                            <div className="relative group">
                              <span className="font-medium">Inquiry Name:</span> {inquiry.enquery_name}
                              <div className="absolute bottom-full left-0 mb-2 px-3 py-1 bg-gray-900 text-white text-xs rounded shadow-lg opacity-0 group-hover:opacity-100 transition-opacity duration-200 whitespace-nowrap z-10">
                                {inquiry.enquery_email}
                                <div className="absolute bottom-0 left-4 transform translate-y-full w-2 h-2 bg-gray-900 rotate-45"></div>
                              </div>
                            </div>
                            <div>
                              <span className="font-medium">Number:</span> {inquiry.enquery_number}
                            </div>
                            <div>
                              <span className="font-medium">Date:</span> {new Date(inquiry.created_at).toLocaleDateString('en-GB')}
                            </div>
                            <div>
                              <span className="font-medium">City:</span> {inquiry.propertyCity}
                            </div>
                            <div>
                              <span className="font-medium">Price:</span> ₹{inquiry.price}
                            </div>
                            <div>
                              <span className="font-medium">Agree to Contact:</span> 
                              {inquiry.agree_contact === 1 ? 'Yes' : 'No'}
                            </div>
                          </div>
                        </div>
                      </div>
                    )}
                  </td>
                </tr>
              </React.Fragment>
            ))}
          </tbody>
        </table>
      </div>
    </div>
  );
};

export default AgentInquiry;